Bias and linearity assess the accuracy of a gage.

- Bias examines the difference between the observed average measurement and a reference value. Bias indicates how accurate the gage is when compared to a reference value.
- Linearity examines how accurate your measurements are through the expected range of the measurements. Linearity indicates whether the gage has the same accuracy across all reference values.

A P-value smaller then 0.05 indicates that a linear equation fits well to the data.

For more information take a look at:

- Measurement System Analysis